@@ -23,12 +23,12 @@ class build_py(build_py_orig):
         pass
 
 
-def artipy(dirname, setup_py, **kwargs):
+def artipy(dirname, setup_py, language_level='3', **kwargs):
     if os.environ.get('DISABLE_ARTIPY') == "1":
         return {}
     else:
         return {
-            'ext_modules': cythonize(find_extensions(dirname, setup_py), **kwargs),
+            'ext_modules': cythonize(find_extensions(dirname, setup_py), language_level=language_level, **kwargs),
             'cmdclass': {'build_py': build_py},
         }
 
